@@ -638,6 +638,25 @@ globus_gridftp_server_control_attr_set_idle_time(
     return GLOBUS_SUCCESS;
 }
 
+globus_result_t
+globus_gridftp_server_control_attr_set_epsv_ip(
+    globus_gridftp_server_control_attr_t    in_attr,
+    globus_bool_t                           epsv_ip)
+{
+    globus_i_gsc_attr_t *                   attr;
+    GlobusGridFTPServerName(globus_gridftp_server_control_attr_set_epsv_ip);
+
+    if(in_attr == NULL)
+    {
+        return GlobusGridFTPServerErrorParameter("server_attr");
+    }
+    attr = (globus_i_gsc_attr_t *) in_attr;
+
+    attr->epsv_ip = epsv_ip;
+
+    return GLOBUS_SUCCESS;
+}
+
 globus_result_t
 globus_gridftp_server_control_attr_set_message(
     globus_gridftp_server_control_attr_t    in_attr,
